duration property

Duration duration
final

After the event delaying is added the stream will wait for at least duration before the event CallbackControllerState.ready is added.

Implementation

final Duration duration;