callback_controller library
Classes
- CallbackController
- Limits the frequency with which a callback is called to one call per duration.
- CallbackDelayer
- Waits for duration before running a callback.
- CallbackLimiter
- Runs the callback as soon as possible and limits the calling frequency to one call per duration.
- TimeStampedCallbackControllerState
Enums
Extensions
Constants
- busy → const CallbackControllerState
- delaying → const CallbackControllerState
- ready → const CallbackControllerState
Functions
-
defaultCallback(
) → FutureOr< void>