CallbackControllerState enum
Values
- ready → const CallbackControllerState
-
Ready state before running the callback.
- busy → const CallbackControllerState
-
Busy state after starting the callback but before the callback has finished.
- delaying → const CallbackControllerState
-
The state after the callback has finished and before the state ready.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isBusy → bool
-
Returns
trueifthis == DebounceState.busyand false otherwise.no setter - isDelaying → bool
-
Returns
trueifthis == DebounceState.resettingand false otherwise.no setter - isNotBusy → bool
-
Returns
trueifthis != DebounceState.busyand false otherwise.no setter - isNotDelaying → bool
-
Returns
trueifthis != DebounceState.resettingand false otherwise.no setter - isNotReady → bool
-
Returns
trueifthis != DebounceState.readyand false otherwise.no setter - isReady → bool
-
Returns
trueifthis == DebounceState.readyand false otherwise.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stamp → TimeStampedCallbackControllerState
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CallbackControllerState> - A constant List of the values in this enum, in order of their declaration.